set.seed(123321)
nrep <- 1000
library(parallel)
RNGkind("L'Ecuyer-CMRG")
seed.l <- list()
s <- .Random.seed
for (i in 1:nrep) {
	seed.l[[i]] <- s
	s <- nextRNGStream(s)
}

FUN <- function(repseed) {
    RNGkind("L'Ecuyer-CMRG")
    assign(".Random.seed", repseed, envir = .GlobalEnv)
	n <- 200
	b <- 0.5
	x <- rnorm(n, 0, 1)
	e <- rnorm(n, 0, sqrt(1 - b^2))
	y <- b*x + e
	dat <- data.frame(x = x, y = y)
	out <- lm(y ~ x, data = dat)
	summary(out)[["coefficients"]][2, c(1, 2, 4)]
}
result <- mclapply(seed.l, FUN, mc.cores = 11)
result <- do.call(rbind, result)
save(result, file=paste("result2.rda", sep=""))
